#!/bin/bash

path="$1/examples"

examples_in="$(dirname $0)/qt4-examples.in"
examples_make="$(dirname $0)/qt4-examples.make"

get_var()
{
	var=$1
	file=$2
	if [ -z "$var" -o -z "$file" ]; then
		echo \"get_var $var $file\" failed!
		exit 1
	fi
	grep $var $file | sed -e 's/.*=[ 	]*//'
}

test_pro()
{
	pro=$1
	template=$(get_var TEMPLATE $pro)
	if [ -z "$template" ]; then
		template=app
	fi
	target=$(get_var TARGET $pro)
	if [ -z "$target" ]; then
		target=$(basename ${pro%%.pro})
	fi
	if [ "$template" = "app" ]; then
		echo $target
	fi
}

cat > $examples_in << EOF
## SECTION=qt
# WARNING: this file is generated with qt4_mk_examples.sh
# do not edit

menuconfig QT4_EXAMPLES
	tristate
	select QT4
	select QT4_PREPARE_EXAMPLES
	prompt "Qt Embedded Examples          "

if QT4_EXAMPLES

config QT4_EXAMPLES__INSTALL_DIR
	string
	default "/usr/bin/qt4-examples"
	prompt "install dir"

EOF

cat > $examples_make << EOF
# WARNING: this file is generated with qt4_mk_examples.sh
# do not edit

ifdef PTXCONF_QT4_EXAMPLES
\$(STATEDIR)/qt4.targetinstall.post: \$(STATEDIR)/qt4-examples.targetinstall
endif

\$(STATEDIR)/qt4-examples.targetinstall: \$(STATEDIR)/qt4.targetinstall
	@\$(call targetinfo, \$@)
	@\$(call install_init, qt4-examples)
	@\$(call install_fixup,qt4-examples,PACKAGE,qt4-examples)
	@\$(call install_fixup,qt4-examples,PRIORITY,optional)
	@\$(call install_fixup,qt4-examples,VERSION,\$(QT4_VERSION))
	@\$(call install_fixup,qt4-examples,SECTION,base)
	@\$(call install_fixup,qt4-examples,AUTHOR,"Robert Schwebel <r.schwebel\@pengutronix.de>")
	@\$(call install_fixup,qt4-examples,DEPENDS,)
	@\$(call install_fixup,qt4-examples,DESCRIPTION,missing)

EOF

for pro in $(find $path -name "*.pro"); do
	target=$(test_pro $pro)
	pro=${pro##$path/}
	if [ -z "$target" ]; then
		continue
	fi
	TARGET=$(echo $target | tr a-z- A-Z_)
	dir=$(dirname $pro)
	target_list="$target_list $dir/$target"
	group=$(dirname $dir)
	if [ "$group" != "$last_group" ]; then
		if [ -n "$last_group" ]; then
			cat >> $examples_in << EOF

endmenu

EOF
		fi
		cat >> $examples_in << EOF

menu "$group"

EOF
		last_group=$group
	fi
	cat >> $examples_in << EOF
config QT4_EXAMPLES__$TARGET
	bool
	prompt "$target"

EOF

	cat >> $examples_make << EOF
ifdef PTXCONF_QT4_EXAMPLES__$TARGET
	@\$(call install_copy, qt4-examples, 0, 0, 0644, \\
		\$(QT4_DIR)/examples/$dir/$target, \\
		\$(PTXCONF_QT4_EXAMPLES__INSTALL_DIR)/$target)
endif

EOF

done

if [ -n "$last_group" ]; then
	cat >> $examples_in << EOF

endmenu

EOF
fi
cat >> $examples_in << EOF

endif

EOF

cat >> $examples_make << EOF

	@\$(call install_finish,qt4-examples)
	@\$(call touch, \$@)

EOF

